## START: Set by rpmautospec
## (rpmautospec version 0.8.2)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:      percolator
Summary:   Software for postprocessing of shotgun proteomics data
Version:   3.08
Release:   %autorelease

## Code under src/ (except RAMP) is licensed under a ASL 2.0 license.
## Code under src/converters/MSToolkit/RAMP is licensed under a LGPLv2+ license.
License:   Apache-2.0 AND LGPL-2.0-or-later
URL:       https://github.com/percolator/percolator
Source0:   https://github.com/percolator/percolator/archive/rel-3-08/percolator-rel-3-08.tar.gz

BuildRequires: make
BuildRequires: gcc, gcc-c++
BuildRequires: cmake

# Needed for testing
BuildRequires: gtest-devel
BuildRequires: eigen3-devel
BuildRequires: python3-devel
BuildRequires: boost-static, boost-devel
BuildRequires: pkgconfig(tokyocabinet)
BuildRequires: pkgconfig(xerces-c)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(libtirpc)
BuildRequires: xsd, zlib-devel, bzip2-devel

Patch0: percolator-unbundle_eigen_gtest.patch

Requires: %{name}-data = %{version}-%{release}
Obsoletes: fido-pi = 0:0

%description
The first step in analyzing an mass spectrometry assay is to match
the harvested spectra against a target database 
using database search engines such as Sequest and Mascot,
a process that renders list of peptide-spectrum matches.
However, it is not trivial to assess the accuracy
of these identifications.

Percolator uses a semi-supervised machine learning to 
discriminate correct from incorrect peptide-spectrum matches,
and calculates accurate statistics such as q-value (FDR)
and posterior error probabilities.

%package data
Summary: percolator data files
BuildArch: noarch
Requires: xml-common

%description data
This package contains XSD data files of %{name} and
models of elude tool.

%package static
Summary: percolator static libraries

%description static
This package contains static libraries of %{name}.

%prep
%autosetup -n percolator-rel-3-08 -N

%patch -P 0 -p1 -b .backup

## Remove spurious executable permissions
find . -type f -name "*.cpp" -exec chmod 0644 '{}' \;
find . -type f -name "*.h" -exec chmod 0644 '{}' \;
find . -type f -name "*.xx" -exec chmod 0644 '{}' \;
find . -type f -name "*.txt" -exec chmod 0644 '{}' \;

# Remove bundled files
rm -rf percolator/_deps/*

## Rename additional readme files
chmod a-x src/converters/MSToolkit/RAMP/README
mv src/converters/MSToolkit/RAMP/README src/converters/MSToolkit/RAMP/RAMP-README
mv src/converters/MSToolkit/RAMP/Readme.Mike.txt src/converters/MSToolkit/RAMP/RAMP-Readme.Mike.txt

## Set 'qvality' destination directory
sed -e 's|./bin|bin|g' -i src/qvality/CMakeLists.txt

%build
export CXXFLAGS="-std=c++14 $RPM_OPT_FLAGS"
mkdir -p percolator
%cmake -Wno-dev -B percolator -S ./ \
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE -DXML_SUPPORT:BOOL=ON \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags} -Isrc -I%{_includedir}/xsd/cxx/tree -I%{_includedir}/tirpc -I%{_includedir}/eigen3" \
 -DCMAKE_EXE_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -ltirpc" \
 -DCMAKE_BUILD_TYPE:STRING=Release -DBUILD_TESTING:BOOL=ON \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DTARGET_ARCH=%{_arch}

### XSD files ran maually
### In Fedora 'xsd' executable is 'xsdcxx'
xsdcxx cxx-tree --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_in/13=percolatorInNs src/xml/percolator_in.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_out/15=percolatorOutNs src/xml/percolator_out.xsd
###

%define _vpath_builddir percolator
%cmake_build

mkdir -p src/fido
%cmake -Wno-dev -B src/fido \
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DTokyoCabinet_INCLUDE_DIR=%{_includedir} \
 -DTokyoCabinet_LIBRARY=%{_libdir}/libtokyocabinet.so \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags} -Isrc -I%{_includedir}/xsd/cxx/tree -I%{_includedir}/tirpc -I%{_includedir}/eigen3" \
 -DCMAKE_EXE_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -ltirpc" \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DTARGET_ARCH=%{_arch} -DBUILD_TESTING:BOOL=ON
 
%define _vpath_builddir src/fido
%cmake_build

mkdir -p src/converters
%cmake -Wno-dev -B src/converters \
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags} -Isrc -I%{_includedir}/xsd/cxx/tree -I%{_includedir}/tirpc -I%{_includedir}/eigen3" \
 -DCMAKE_EXE_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -ltirpc" \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DPERCOLATOR-CONVERTERS_BINARY_DIR:STATIC=converters \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DTokyoCabinet_INCLUDE_DIR=%{_includedir} \
 -DTokyoCabinet_LIBRARY=%{_libdir}/libtokyocabinet.so \
 -DSERIALIZE="TokyoCabinet" \
 -DTARGET_ARCH=%{_arch} -DBUILD_TESTING:BOOL=ON

### XSD files ran maually
### In Fedora 'xsd' executable is 'xsdcxx'
xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_in/13=percolatorInNs src/xml/percolator_in.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_out/15=percolatorOutNs src/xml/percolator_out.xsd
##
xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://psidev.info/psi/pi/mzIdentML/1.1=mzIdentML_ns src/xml/mzIdentML1.1.0.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://www.bioml.com/gaml/=gaml_tandem_ns src/xml/gaml_tandem1.0.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://www.thegpm.org/TANDEM/2011.12.01.1=tandem_ns --namespace-map =tandem_ns \
 --namespace-map http://www.bioml.com/gaml/=gaml_tandem_ns src/xml/tandem2011.12.01.1.xsd
###

%define _vpath_builddir src/converters
%cmake_build

%install
%define _vpath_builddir percolator
%cmake_install

%define _vpath_builddir src/converters
%cmake_install

## Install static libraries
mkdir -p %{buildroot}%{_libdir}/percolator
for i in `find . -type f \( -name "*.a" \)`; do
 install -pm 755 $i %{buildroot}%{_libdir}/percolator
done

rm -f %{buildroot}%{_bindir}/gtest_unit

%check
%define _vpath_builddir percolator
# https://github.com/percolator/percolator/issues/354
%ifarch %{ix86}
# nothing
%else
%ctest -VV
%endif

%files
%{_bindir}/percolator
%{_bindir}/qvality

%files data
%doc ReadMe.txt
%doc src/converters/MSToolkit/RAMP/RAMP-*
%license license.txt
%{_datadir}/xml/percolator/

%files static
%doc ReadMe.txt
%doc src/converters/MSToolkit/RAMP/RAMP-*
%license license.txt
%{_libdir}/percolator/

%changelog
## START: Generated by rpmautospec
* Wed Jul 23 2025 Antonio Trande <sagitter@fedoraproject.org> - 3.08-1
- Release 3.08 (rhbz#2381357)

* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.06.04-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Oct 18 2024 Pete Walter <pwalter@fedoraproject.org> - 3.06.04-5
- Rebuild for xerces-c 3.3

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.06.04-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.06.04-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.06.04-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Dec 08 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.04-1
- Release 3.06.04

* Sun Dec 03 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.03-2
- Fix name of main directory

* Sun Dec 03 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.03-1
- Release 3.06.03

* Sun Nov 19 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.02-1
- Release 3.06.02

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.06.01-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sun Jul 02 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.01-5
- Exclude tests on i686

* Sun Jul 02 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.01-4
- Exclude some tests on i686

* Sat Jun 17 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.01-3
- Remove converters tests

* Thu Jun 15 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.01-2
- Fix tests

* Thu Jun 15 2023 Antonio Trande <sagitter@fedoraproject.org> - 3.06.01-1
- Release 3.06.01| Elude support dropped

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Feb 16 2021 Antonio T <sagitter@fedoraproject.org> - 3.05-10
- Undo latest file deletion

* Tue Feb 16 2021 Antonio T <sagitter@fedoraproject.org> - 3.05-9
- Obsolete fido-pi (Fedora 34+)

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 08 2021 Tom Stellard <tstellar@redhat.com> - 3.05-7
- Add BuildRequires: make

* Wed Aug 19 2020 Jeff Law <law@redhat.com> - 3.05-6
- Force C++14 as this code is not C++17 ready

* Tue Aug 04 2020 sagitter <sagitter@fedoraproject.org> - 3.05-5
- Enable __cmake_in_source_build

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.05-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 19 2020 sagitter <sagitter@fedoraproject.org> - 3.05-2
- Fix EPEL7 builds (use boost169)

* Tue May 19 2020 sagitter <sagitter@fedoraproject.org> - 3.05-1
- Release 3.05

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.04-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Sep 21 2019 sagitter <sagitter@fedoraproject.org> - 3.04-1
- Release 3.04

* Thu Jul 25 2019 sagitter <sagitter@fedoraproject.org> - 3.03-1
- Release 3.03

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.02.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.02.01-2
- Fix RHEL conditions

* Sat Nov 03 2018 sagitter <sagitter@fedoraproject.org> - 3.02.01-1
- Release 3.02.01

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.02.00-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 22 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-6
- Add gcc gcc-c++ BR

* Sat Feb 17 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-5
- Link to libtirpc on fedora only

* Sat Feb 17 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-4
- Link to libtirpc

* Thu Feb 15 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-3
- Add tirpc cflag manually

* Thu Feb 15 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-2
- Add libtirpc BR

* Thu Feb 15 2018 sagitter <sagitter@fedoraproject.org> - 3.02.00-1
- Update to 3.02.0

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.01.02-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Oct 15 2017 sagitter <sagitter@fedoraproject.org> - 3.01.02-1
- Update to 3.01.02

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.01-6
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.01-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Jul 08 2017 sagitter <sagitter@fedoraproject.org> - 3.01-4
- URL changed to GitHub

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 01 2017 Jonathan Wakely <jwakely@redhat.com> - 3.01-2
- Rebuilt for Boost 1.63 and patched for GCC 7

* Thu Nov 17 2016 sagitter <sagitter@fedoraproject.org> - 3.01-1
- Update to 3.01

* Thu Jun 09 2016 sagitter <sagitter@fedoraproject.org> - 3.0-1
- Update to 3.0

* Mon Feb 15 2016 sagitter <sagitter@fedoraproject.org> - 2.10.1-10
- Fixed cflags to Boost148 (EPEL)

* Fri Feb 05 2016 sagitter <sagitter@fedoraproject.org> - 2.10.1-9
- Update to commit #a4d14b

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.10.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 2.10.1-7
- Rebuilt for Boost 1.60

* Wed Dec 23 2015 sagitter <sagitter@fedoraproject.org> - 2.10.1-6
- Used always 'cmake' command

* Sat Nov 14 2015 sagitter <sagitter@fedoraproject.org> - 2.10.1-5
- Packaging upgrade for EPEL

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 2.10.1-4
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Dennis Gilmore <dennis@ausil.us> - 2.10.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Sat Jul 18 2015 sagitter <sagitter@fedoraproject.org> - 2.10.1-2
- Rebuild for Boost upgrade to 1.58.0

* Wed Jul 08 2015 sagitter <sagitter@fedoraproject.org> - 2.10.1-1
- Update to 2.10.1

* Thu Jun 18 2015 Dennis Gilmore <dennis@ausil.us> - 2.09.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 25 2015 sagitter <sagitter@fedoraproject.org> - 2.09.0-1
- New package (bz#1224385)
## END: Generated by rpmautospec
